"""\
This setup.py was provided by `package`, the Python package package package.

See http://pypi.python.org/pypi/package/ for more information.
"""

import sys
sys.path.insert(0, '')
import package
package.setup()
